from django import forms

import json


class BaseCroppieWidget(forms.FileInput):
    class Media:
        css = {
            'all': (
                'croppie/croppie.css',
            )
        }
        js = (
            'croppie/croppie.min.js',
            'croppie/form-process.js',
        )

    def __init__(self, options, *args, **kwargs):
        self.croppie_options = options
        super(BaseCroppieWidget, self).__init__(*args, **kwargs)

    def process_croppie_context(self, name):
        name = name.replace('_0', '')
        return {
            'croppie_options': json.dumps(self.croppie_options),
            'croppie_field_name': name,
        }



from .base import BaseCroppieWidget


class CroppieWidget(BaseCroppieWidget):
    """
        Widget for Django.VERSION >= 11
    """

    template_name = 'croppie/widget.html'

    def get_context(self, name, value, attrs):
        context = super(CroppieWidget, self).get_context(name, value, attrs)
        name = context['widget'].get('name')
        context['widget'].update(
            self.process_croppie_context(name)
        )
        return context



from django.utils.html import format_html, mark_safe

from .base import BaseCroppieWidget


class CroppieWidget(BaseCroppieWidget):
    """
        Widget for Django.VERSION < 11 as old versions
        of django does not support templates in widgets.
    """

    def render(self, name, value, attrs=None):
        html = super(CroppieWidget, self).render(name, value, attrs)
        html += format_html(
            '<script type="text/javascript">{}</script>',
            self.make_script_vars(name),
        )
        return html

    def make_script_vars(self, name):
        context = self.process_croppie_context(name)
        vars = 'var croppieFieldName = "{}"\n var croppieOptions = {}' \
            .format(
                context['croppie_field_name'],
                context['croppie_options'],
            )
        return mark_safe(vars)



import os
from setuptools import find_packages, setup

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


setup(
    name='django-croppie',
    version='1.1',
    packages=find_packages(),
    license='MIT',
    include_package_data=True,
    description='Application for easy croppie.js integration to django',
    author='Dima Kovalchuk',
    author_email='dmyutro@ukr.net',
    url='https://github.com/dima-kov/django-croppie',
    download_url='https://github.com/dima-kov/django-croppie/archive/v1.0.tar.gz',
    keywords=[
        'python', 'django', 'croppie', 'croppie.js',
        'image-processing', 'image-cropping',
    ],
    install_requires=[],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



import django
from django import forms

if django.VERSION[1] < 11:
    from .widgets_old import CroppieWidget
else:
    from .widgets import CroppieWidget


class CroppieImageRatioWidget(forms.MultiWidget):
    def __init__(self, options, *args, **kwargs):
        widgets = (
            CroppieWidget(options=options),
            forms.HiddenInput(),
            forms.HiddenInput(),
            forms.HiddenInput(),
            forms.HiddenInput(),
        )
        super(CroppieImageRatioWidget, self).__init__(
            widgets=widgets,
            *args, **kwargs
        )

    def decompress(self, value):
        if value:
            return [value, None, None, None, None]
        return [None, None, None, None, None]



from django import forms
from django.core.files.uploadedfile import InMemoryUploadedFile

import io
from PIL import Image

from croppie.widgets import CroppieImageRatioWidget


class CroppieField(forms.MultiValueField):

    def __init__(self, options={}, widget=None, *args, **kwargs):
        fields = (
            forms.ImageField(),
            forms.CharField(),
            forms.CharField(),
            forms.CharField(),
            forms.CharField(),
        )
        if widget is None:
            widget = CroppieImageRatioWidget(options=options)

        super(CroppieField, self).__init__(
            fields=fields, widget=widget, *args, **kwargs)

    def compress(self, data_list):
        data_image = data_list[0]
        ratio = data_list[1:]
        ratio = [int(i) for i in ratio]
        return self.crop_image(data_image, ratio)

    def crop_image(self, data_image, ratio):
        image = Image.open(data_image)
        cropped_image = image.crop(ratio)

        # saving image to memory
        thumb_io = io.BytesIO()
        cropped_image.save(
            thumb_io,
            data_image.content_type.split('/')[-1].upper()
        )

        # creating new InMemoryUploadedFile() based on the modified file
        file = InMemoryUploadedFile(
            thumb_io,
            'photo',
            data_image._get_name(),
            data_image.content_type,
            None, None,
        )
        return file
